# Easy PIL
![Lint-Test](https://github.com/shahriyardx/easy-pil/actions/workflows/lint-test.yml/badge.svg)

A Python library built on top of [PIL](https://github.com/python-pillow/Pillow) to easily edit/modify images.

## Getting Started
Using this for the first time? Here are some links to help you get started.

- Read the [docs](https://easy-pil.readthedocs.io/en/latest/)
- First steps [Introduction](https://easy-pil.readthedocs.io/en/latest/pages/intro.html)
- Integrate in a [Discord bot](https://easy-pil.readthedocs.io/en/latest/pages/discordbot.html)
- Some premade [Examples](https://github.com/shahriyardx/easy-pil/tree/master/examples)
- [Report bugs](https://github.com/shahriyardx/easy-pil/issues/)

## Get help
- Ask us in our [Discord server](https://discord.gg/fVzt5THTNb)
- Watch [Youtube Tutorials](https://www.youtube.com/playlist?list=PLb_oBhGqAlbT4yVqV0TSXggA8b0lZhGhn)
